aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/gl/GrGLProgramDesc.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gpu/gl/GrGLProgramDesc.h')
-rw-r--r--src/gpu/gl/GrGLProgramDesc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gpu/gl/GrGLProgramDesc.h b/src/gpu/gl/GrGLProgramDesc.h
index b53daeb444..401ce222fb 100644
--- a/src/gpu/gl/GrGLProgramDesc.h
+++ b/src/gpu/gl/GrGLProgramDesc.h
@@ -13,7 +13,7 @@
#include "GrGpu.h"
#include "GrTypesPriv.h"
-class GrGpuGL;
+class GrGLGpu;
/**
* This class can be used to build a GrProgramDesc. It also provides helpers for accessing
@@ -52,7 +52,7 @@ public:
* @param DescInfo A descriptor info struct, generated by the optstate, which contains a number
* of important facts about the program the built descriptor will represent
* @param DrawType
* @param GrGpuGL A GL Gpu, the caps and Gpu object are used to output processor specific
* parts of the descriptor.
* @param GrDeviceCoordTexture A dstCopy texture, which may be null if frame buffer fetch is
* supported
@@ -61,7 +61,7 @@ public:
static bool Build(const GrOptDrawState&,
const GrProgramDesc::DescInfo&,
GrGpu::DrawType,
- GrGpuGL*,
+ GrGLGpu*,
GrProgramDesc*);
static const GLKeyHeader& GetHeader(const GrProgramDesc& desc) {
@@ -52,7 +52,7 @@ public:
* of important facts about the program the built descriptor will represent
* @param DrawType
- * @param GrGpuGL A GL Gpu, the caps and Gpu object are used to output processor specific
+ * @param GrGLGpu A GL Gpu, the caps and Gpu object are used to output processor specific
* parts of the descriptor.
* @param GrDeviceCoordTexture A dstCopy texture, which may be null if frame buffer fetch is